# coding: utf-8
import settings

from django.contrib.auth.models import AnonymousUser
from m3.ui.actions import ActionPack

from .helpers import remember_user, memorize_user
from .models import DataLog
from .enums import EventCode

__author__ = 'Andrey Torsunov'
__contact__ = 'torsunov@bars-open.com'
__docformat__ = 'restructuredtext'


orig_pre_run = ActionPack.pre_run
orig_post_run = ActionPack.post_run


def _invader_pre_run(self, request, context):
    memorize_user(request.user)
    return orig_pre_run(self, request, context)


def _invader_post_run(self, request, context, response):
    user = remember_user()
    if hasattr(response, 'data') and hasattr(response.data, 'title'):
        win = response.data
        DataLog.make_system_event(EventCode.WIN_OPEN, {
            'title': win.title
        })
    elif isinstance(request.user, AnonymousUser) and user != request.user:
        DataLog.make_system_event(EventCode.LOGOUT)
    elif isinstance(user, AnonymousUser) and user != request.user:
        DataLog.make_system_event(EventCode.LOGIN)
    return orig_post_run(self, request, context, response)


ActionPack.pre_run = _invader_pre_run
ActionPack.post_run = _invader_post_run
